@@ -70,14 +70,30 @@ def needed_TAs(event):
     num_TAs = round(num_TAs * 1.5)
 
   return num_TAs
+
+def event_filter(events):
+  """
+  Takes a list of events, returns a filtered list of events (generator).
+  The events to include are the teaching events.
+  """
+  events_whitelist = ["Datorlaboration", "Laboration", "Föreläsning", "Övning"]
+
+  for event in events:
+    for event_type in events_whitelist:
+      if event_type in event.name:
+        yield event
+        break
   
-def generate_signup_sheet(course, url, needed_TAs=needed_TAs):
+def generate_signup_sheet(course, url,
+  needed_TAs=needed_TAs, event_filter=event_filter):
   """
   Input:
   - course is a string containing the file name used for output.
   - url is the URL to the ICS-formatted calendar.
   - needed_TAs is a function computing the number of needed TAs based on the 
-    event. The default is the needed_TAs function in this module.
+    event. The default is the needed_TAs function in this module,
+  - event_filter is a function that filters events, takes a list of events as 
+    argument and returns a filtered list.
 
   Output:
   Returns nothing. Writes output to {course}.csv.
@@ -89,20 +105,19 @@ def generate_signup_sheet(course, url, needed_TAs=needed_TAs):
     max_num_TAs = 0
     rows = []
 
-    for event in calendar.timeline:
-      if "Övning" in event.name or \
-          "laboration" in event.name or "Laboration" in event.name:
-        num_TAs = needed_TAs(event)
-        if num_TAs > max_num_TAs:
-          max_num_TAs = num_TAs
+    for event in event_filter(calendar.timeline):
+      num_TAs = needed_TAs(event)
 
-        rows.append([
-          event.name,
-          event.begin.to("local").format("YYYY-MM-DD HH:mm"),
-          event.end.to("local").format("YYYY-MM-DD HH:mm"),
-          len(event.location.split(",")),
-          num_TAs
-        ])
+      if num_TAs > max_num_TAs:
+        max_num_TAs = num_TAs
+
+      rows.append([
+        event.name,
+        event.begin.to("local").format("YYYY-MM-DD HH:mm"),
+        event.end.to("local").format("YYYY-MM-DD HH:mm"),
+        len(event.location.split(",")),
+        num_TAs
+      ])
 
     csvout.writerow(SIGNUP_SHEET_HEADER +
       [f"TA username" for n in range(max_num_TAs)] +
